<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb">
<context>
    <name>ConkyCustomizeDialog</name>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="56"/>
        <source>Customize Conky - %1</source>
        <translation>Tilpass Conky — %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="77"/>
        <source>Launch</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="81"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="83"/>
        <source>Undo</source>
        <translation>Angre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="106"/>
        <location filename="../src/conkycustomizedialog.cpp" line="186"/>
        <source>Colors</source>
        <translation>Farger</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Default</source>
        <translation>Forvalgt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color0</source>
        <translation>Farge0</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color1</source>
        <translation>Farge1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color2</source>
        <translation>Farge2</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color3</source>
        <translation>Farge3</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="121"/>
        <source>Color4</source>
        <translation>Farge4</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color5</source>
        <translation>Farge5</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color6</source>
        <translation>Farge6</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color7</source>
        <translation>Farge7</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color8</source>
        <translation>Farge8</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="122"/>
        <source>Color9</source>
        <translation>Farge9</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="193"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="337"/>
        <location filename="../src/conkycustomizedialog.cpp" line="342"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="713"/>
        <source>Select Color</source>
        <translation>Velg farge</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="819"/>
        <source>Permission Denied</source>
        <translation>Mangler rettigheter</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="820"/>
        <source>Cannot write to file: %1
Insufficient permissions.</source>
        <translation>Kan ikke skrive til fil: %1
Mangler rettigheter.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Write Error</source>
        <translation>Skrivefeil</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="830"/>
        <source>Cannot write to file: %1</source>
        <translation>Kan ikke skrive til fil: %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Backup Config File</source>
        <translation>Reservekopier oppsettsfil</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="921"/>
        <source>Do you want to preserve the original file?</source>
        <translation>Vil du bevare originalfilen?</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="945"/>
        <source>Backed Up Config File</source>
        <translation>Reservekopierte oppsettsfila</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="946"/>
        <source>The original configuration was backed up to %1</source>
        <translation>Det originale oppsettet ble reservekopiert til %1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Backup Failed</source>
        <translation>Reservekopiering mislyktes</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="948"/>
        <source>Failed to create a backup file.</source>
        <translation>Klarte ikke opprette reservekopi.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Restore Failed</source>
        <translation>Gjenoppretting mislyktes</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1029"/>
        <source>Failed to restore from backup file.</source>
        <translation>Klarte ikke gjenopprette fra reservekopi.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1032"/>
        <source>Backup file does not exist.</source>
        <translation>Reservekopi finnes ikke.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1384"/>
        <source>Position</source>
        <translation>Posisjon</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1391"/>
        <source>Alignment</source>
        <translation>Justering</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1396"/>
        <source>Top Left</source>
        <translation>Oppe til venstre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1397"/>
        <source>Top Right</source>
        <translation>Oppe til høyre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1398"/>
        <source>Top Middle</source>
        <translation>Oppe i midten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1399"/>
        <source>Bottom Left</source>
        <translation>Nede til venstre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1400"/>
        <source>Bottom Right</source>
        <translation>Nede til høyre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1401"/>
        <source>Bottom Middle</source>
        <translation>Nede i midten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1402"/>
        <source>Middle Left</source>
        <translation>I midten til venstre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1403"/>
        <source>Middle Right</source>
        <translation>I midten til høyre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1404"/>
        <source>Middle Middle</source>
        <translation>Midt i midten</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1409"/>
        <source>Horizontal Gap</source>
        <translation>Vannrett glipe</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1410"/>
        <source>[GAP_X] Horizontal distance from window border (in pixels)</source>
        <translation>[GAP_X] Vannrett avstand fra vinduskanten (i piksler)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1422"/>
        <source>Vertical Gap</source>
        <translation>Loddrett glipe</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1423"/>
        <source>[GAP_Y] Vertical distance from window border (in pixels)</source>
        <translation>[GAP_Y] Loddrett avstand fra vinduskanten (i piksler)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1435"/>
        <source>Desktop</source>
        <translation>Skrivebord</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1438"/>
        <source>Desktop 1</source>
        <translation>Skrivebord 1</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1439"/>
        <source>All Desktops</source>
        <translation>Alle skrivebord</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1451"/>
        <source>Location</source>
        <translation>Plassering</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1463"/>
        <source>Width should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Bredden må være lenger enn størrelsen til vindusinnholdet,
ellers vil ikke denne innstillingen ha noen effekt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1467"/>
        <source>Minimum Width</source>
        <translation>Minste bredde</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1482"/>
        <source>Height should be larger than the size of window contents,
otherwise this setting will not have any effect</source>
        <translation>Høyden må være lenger enn størrelsen til vindusinnholdet,
ellers vil ikke denne innstillingen ha noen effekt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1484"/>
        <source>Minimum Height</source>
        <translation>Minste høyde</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1498"/>
        <source>Increases the window height by adding empty lines at the end of the Conky config file</source>
        <translation>Øker vindushøyden ved å legge til tomme linjer i slutten av oppsettsfila til Conky</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1499"/>
        <source>Height Padding</source>
        <translation>Polstring av høyde</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1514"/>
        <source>Size</source>
        <translation>Str</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1527"/>
        <source>Transparency Type</source>
        <translation>Gjennomsiktighetstype</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1532"/>
        <source>Opaque</source>
        <translation>Heldekkende</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1533"/>
        <source>Transparent</source>
        <translation>Gjennomsiktig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1534"/>
        <source>Pseudo-Transparent</source>
        <translation>Pseudo-gjennomsiktig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1535"/>
        <source>Semi-Transparent</source>
        <translation>Semi-gjennomsiktig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1540"/>
        <source>Opacity (%)</source>
        <translation>Dekkevne (%)</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1541"/>
        <source>Window Opacity

0 = Fully Transparent, 100 = Fully Opaque</source>
        <translation>Vindusgjennomsiktighet

0 = Helt gjennomsiktig, 100 = Ikke gjennomsiktig</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1555"/>
        <source>Background Color</source>
        <translation>Bakgrunnsfarge</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1560"/>
        <source>Choose Color</source>
        <translation>Velg farge</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1580"/>
        <source>Setting Type to &quot;Transparent&quot; will make the whole window transparent (including any images). Use &quot;Pseudo-Transparent&quot; if you want the images to be opaque.</source>
        <translation>Dersom typen er «gjennomsiktig», så vil hele vinduet være gjennomsiktig (også alle bilder). Velg «pseudo-gjennomsiktig» hvis ikke bildene skal være gjennomsiktige.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1590"/>
        <source>Setting Type to &quot;Pseudo-Transparent&quot; will make the window transparent but the window will have a shadow. The shadow can be disabled by configuring your window manager.</source>
        <translation>Dersom typen er «pseudo-gjennomsiktig», så vil vinduet være gjennomsiktig, men vinduet vil ha en skygge. Skyggen kan slås av i innstillingene til vindusbehandleren.</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1601"/>
        <source>Transparency</source>
        <translation>Gjennomsiktighet</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1612"/>
        <source>Date Format</source>
        <translation>Datoformat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1615"/>
        <source>Day</source>
        <translation>Dag</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1617"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1628"/>
        <source>Long</source>
        <translation>Lang</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1618"/>
        <location filename="../src/conkycustomizedialog.cpp" line="1629"/>
        <source>Short</source>
        <translation>Kort</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1619"/>
        <source>Abbreviated name, e.g. Tu</source>
        <translation>Forkortet navn, f.eks. Fre</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1626"/>
        <source>Month</source>
        <translation>Måned</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1630"/>
        <source>Abbreviated name, e.g. Oct</source>
        <translation>Forkortet navn, f.eks. Okt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1649"/>
        <source>Time Format</source>
        <translation>Tidsformat</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1656"/>
        <source>Format</source>
        <translation>Formater</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1661"/>
        <source>12 Hour</source>
        <translation>12 timer</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1662"/>
        <source>24 Hour</source>
        <translation>24 timer</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1663"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1678"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Dato og tid</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1691"/>
        <source>Interface</source>
        <translation>Grensesnitt</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1699"/>
        <source>WiFi</source>
        <translation>WiFi</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1702"/>
        <source>WiFi Network</source>
        <translation>WiFi-nettverk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1705"/>
        <source>LAN</source>
        <translation>LAN</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1708"/>
        <source>Wired LAN Network</source>
        <translation>Kablet LAN-nettverk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="1722"/>
        <source>Network</source>
        <translation>Nettverk</translation>
    </message>
    <message>
        <location filename="../src/conkycustomizedialog.cpp" line="2037"/>
        <source>Select Background Color</source>
        <translation>Velg bakgrunnsfarge</translation>
    </message>
</context>
<context>
    <name>ConkyItemWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Running</source>
        <translation>Kjører</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="64"/>
        <source>Stopped</source>
        <translation>Stoppet</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="138"/>
        <source>Autostart</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="140"/>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="143"/>
        <source>Customize</source>
        <translation>Tilpass</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="148"/>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="177"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="180"/>
        <source>Start</source>
        <translation>Start</translation>
    </message>
</context>
<context>
    <name>ConkyListWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="344"/>
        <source>Total: 0 conkies</source>
        <translation>Total: 0 conkier</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="598"/>
        <source>Total: %1 conkies</source>
        <translation>Total: %1 conkier</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="601"/>
        <source>Showing: %1 of %2 conkies</source>
        <translation>Viser: %1 av %2 conkier</translation>
    </message>
</context>
<context>
    <name>ConkyPreviewWidget</name>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="550"/>
        <source>No Conky Selected</source>
        <translation>Ingen conky valgt</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="552"/>
        <source>Select a conky from the list to see its preview</source>
        <translation>Velg en conky fra listen for å se forhåndsvisningen</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="571"/>
        <source>Preview image could not be loaded</source>
        <translation>Klarte ikke laste forhåndsvisningen</translation>
    </message>
    <message>
        <location filename="../src/conkylistwidget.cpp" line="574"/>
        <source>No preview image available</source>
        <translation>Ingen forhåndsvisning tilgjengelig</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="58"/>
        <location filename="../src/mainwindow.cpp" line="849"/>
        <source>MX Conky</source>
        <translation>MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>About this application</source>
        <translation>Om dette programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="248"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="255"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="270"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="268"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="158"/>
        <source>Loading Conky configurations...</source>
        <translation>Laster Conky-oppsett …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="188"/>
        <source>Settings</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <source>Configure conky search paths</source>
        <translation>Sett opp søkestiene til conkier</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="192"/>
        <source>Refresh</source>
        <translation>Oppdater</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Refresh conky list</source>
        <translation>Oppdater liste over conkier</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="196"/>
        <source>Start All</source>
        <translation>Vis alle</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="198"/>
        <source>Start all enabled conkies</source>
        <translation>Start alle aktiverte conkier</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="200"/>
        <source>Stop All</source>
        <translation>Stopp alle</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="202"/>
        <source>Stop all running conkies</source>
        <translation>Stopp alle kjørende conkier</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="951"/>
        <location filename="../src/mainwindow.cpp" line="995"/>
        <source>Running</source>
        <translation>Kjører</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="953"/>
        <location filename="../src/mainwindow.cpp" line="996"/>
        <source>Stopped</source>
        <translation>Stoppet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="210"/>
        <source>Search conky by name...</source>
        <translation>Søk opp conky etter navn …</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="212"/>
        <source>Search conkies by name (Ctrl+F)</source>
        <translation>Søk opp conkier etter navn (Ctrl + F)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="257"/>
        <source>Display help</source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="433"/>
        <location filename="../src/mainwindow.cpp" line="607"/>
        <source>Copy Conky</source>
        <translation>Kopier conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="479"/>
        <location filename="../src/mainwindow.cpp" line="655"/>
        <source>Conky Copied</source>
        <translation>Conky kopiert</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="480"/>
        <source>Conky has been copied to your personal folder for editing:
%1</source>
        <translation>Conky ble kopiert til hjemmemappa di for redigering:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Copy Failed</source>
        <translation>Kopiering mislyktes</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="482"/>
        <location filename="../src/mainwindow.cpp" line="658"/>
        <source>Failed to copy conky to your personal folder.</source>
        <translation>Klarte ikke kopiere conky til hjemmemappa di.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="544"/>
        <source>Delete Conky</source>
        <translation>Slett conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="656"/>
        <source>Conky has been copied to your personal folder for customization:
%1</source>
        <translation>Conky ble kopiert til hjemmemappa di for tilpasning:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="184"/>
        <source>Previews</source>
        <translation>Forhåndsvisninger</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="186"/>
        <source>Generate preview images for conkies</source>
        <translation>Generer forhåndsvisninger av conkier</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="206"/>
        <location filename="../src/mainwindow.cpp" line="467"/>
        <location filename="../src/mainwindow.cpp" line="643"/>
        <location filename="../src/mainwindow.cpp" line="949"/>
        <location filename="../src/mainwindow.cpp" line="994"/>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="207"/>
        <source>Filter conkies by running status or location</source>
        <translation>Filtrer conkier etter kjørestatus eller plassering</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="429"/>
        <location filename="../src/mainwindow.cpp" line="603"/>
        <source>Enter a name for the copy:</source>
        <translation>Angi navn for kopien:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="430"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>In order for you to edit and save a conky, it must first be copied to ~/.conky where you have permission.
Enter a name for the copy.</source>
        <translation>For å kunne redigere og lagre en conky, må den først kopieres til ~/.conky der du har rettigheter.
Angi et navn for kopien.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="447"/>
        <location filename="../src/mainwindow.cpp" line="623"/>
        <source>Directory Exists</source>
        <translation>Mappa eksisterer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="448"/>
        <location filename="../src/mainwindow.cpp" line="624"/>
        <source>A conky with the name '%1' already exists in your personal folder.
Do you want to overwrite it?</source>
        <translation>En conky som heter «%1» finnes allerede i hjemmemappa di.
Vil du overskrive den?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="515"/>
        <source>Edit Conky</source>
        <translation>Rediger conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="516"/>
        <source>This conky file is read-only and requires administrator privileges to edit.
Do you want to edit it with elevated privileges?</source>
        <translation>Denne conky-filen kan ikke skrives til uten administratorrettigheter.
Vil du redigere den med forhøyede privilegier?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="545"/>
        <source>Are you sure you want to delete the conky file:
%1

This action cannot be undone.</source>
        <translation>Vil du virkelig slette denne conky-fila:
%1

Denne handlingen kan ikke angres.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Delete Failed</source>
        <translation>Sletting mislyktes</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <source>Failed to delete conky file:
%1</source>
        <translation>Klarte ikke slette conky-fil:
%1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>Customize Conky</source>
        <translation>Tilpass Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="666"/>
        <source>This conky file is read-only and requires administrator privileges to customize.
Do you want to customize it with elevated privileges?</source>
        <translation>Denne conky-filen kan ikke tilpasses uten administratorrettigheter.
Vil du tilpasse den med forhøyede privilegier?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Editor Error</source>
        <translation>Redigeringsfeil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="838"/>
        <source>Cannot start editor for file: %1</source>
        <translation>Kan ikke starte redigering av fila: %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="848"/>
        <source>About MX Conky</source>
        <translation>Om MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="850"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="851"/>
        <source>GUI program for configuring Conky in MX Linux</source>
        <translation>Grafisk verktøy for oppsett av Conky i MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="854"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett © MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="855"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="856"/>
        <location filename="../src/mainwindow.cpp" line="868"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="857"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="879"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="910"/>
        <source>MX Conky Help</source>
        <translation>Hjelp for MX Conky</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="955"/>
        <location filename="../src/mainwindow.cpp" line="997"/>
        <source>Autostart</source>
        <translation>Autostart</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <location filename="../src/previewdialog.cpp" line="50"/>
        <source>Generate Preview</source>
        <translation>Lag forhåndsvisning</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="75"/>
        <source>Generate preview images for</source>
        <translation>Lag forhåndsvisninger for</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="78"/>
        <source>Selected Widget</source>
        <translation>Valgt skjermelement</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="79"/>
        <source>All Widgets with Missing Previews</source>
        <translation>Alle skjermelementer som mangler forhåndsvisninger</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="80"/>
        <source>All Widgets (Overwrite Existing Images)</source>
        <translation>Alle skjermelementer (overskriv eksisterende bilder)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="85"/>
        <source>No conky is currently selected</source>
        <translation>Ingen conky er valgt</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="93"/>
        <source>Options</source>
        <translation>Alternativer</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="96"/>
        <source>High quality images (PNG)</source>
        <translation>Høykvalitetsbilder (PNG)</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="97"/>
        <source>Generate preview images in PNG format instead of JPEG</source>
        <translation>Lag forhåndsvisninger i PNG-format i stedet for JPEG</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="114"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="118"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No Items</source>
        <translation>Ingen elementer</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="145"/>
        <source>No conky widgets need preview generation.</source>
        <translation>Ingen conkier trenger nye forhåndsvisninger.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="151"/>
        <source>Missing Dependency</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="152"/>
        <source>Preview generation requires the GraphicsMagick compatibility tools.
Please install the graphicsmagick-imagemagick-compat package to enable this feature.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="163"/>
        <source>Starting preview generation...</source>
        <translation>Starter produksjon av forhåndsvisninger …</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="167"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="206"/>
        <source>Generating preview for: %1</source>
        <translation>Lager forhåndsvisning for: %1</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="427"/>
        <source>Preview generation complete! Generated %1 previews.</source>
        <translation>Har laget alle forhåndsvisningene, totalt %1 stykk.</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="431"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="434"/>
        <source>Preview Generation Complete</source>
        <translation>Ferdig med å lage forhåndsvisninger</translation>
    </message>
    <message>
        <location filename="../src/previewdialog.cpp" line="435"/>
        <source>Successfully generated %1 preview images.</source>
        <translation>Laget %1 forhåndsvisninger.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="67"/>
        <source>Select Conky Manager config file</source>
        <translation>Velg oppsettsfil for Conky-behandling</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="112"/>
        <source>You must run this program as normal user</source>
        <translation>Du må kjøre programmet som en vanlig bruker</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../src/settingsdialog.cpp" line="40"/>
        <location filename="../src/settingsdialog.cpp" line="62"/>
        <source>Select Conky Directory</source>
        <translation>Velg conky-mappe</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="83"/>
        <source>MX Conky Settings</source>
        <translation>Innstillinger for MX Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="91"/>
        <source>Search Paths</source>
        <translation>Søkestier</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="92"/>
        <source>Autostart</source>
        <translation>Autostart</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="167"/>
        <source>Conky Search Paths</source>
        <translation>Søkestier for Conky</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="173"/>
        <source>Add Path</source>
        <translation>Legg til sti</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="176"/>
        <source>Remove Path</source>
        <translation>Fjern sti</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="179"/>
        <source>Edit Path</source>
        <translation>Rediger sti</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="206"/>
        <source>Autostart Settings</source>
        <translation>Innstilling av autostart</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="209"/>
        <source>Start conky at system startup</source>
        <translation>Start conky ved systemoppstart</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="212"/>
        <source>Startup delay (seconds):</source>
        <translation>Oppstartsforsinkelse (sekunder):</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="95"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/settingsdialog.cpp" line="96"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
</TS>